@@ -14,9 +14,9 @@ def crop(input_file, page_option: list):
     space, threshold = (5, 0.008)
     for option in page_option:
         page_no, output_file = option[:2]
-        if len(option > 2):
+        if len(option) > 2:
             space = option[2]
-        if len(option > 3):
+        if len(option) > 3:
             space = option[3]
         pdf_crop = PymuPDFCrop(input_file=input_file, space=space, threshold=threshold)
         output_file, media_box, crop_box = pdf_crop.crop(page_no, output_file=output_file, crop_box=None)
